package com.muyu.marketing.team.controller;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.marketing.domain.model.ActivityTeamInfoAddModel;
import com.muyu.marketing.domain.model.ActivityTeamInfoListModel;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuInfoModel;
import com.muyu.marketing.domain.req.ActivityTeamInfoSaveReq;
import com.muyu.marketing.domain.req.TeamInfoListReq;
import com.muyu.marketing.domain.resp.ActivityTeamDetailResp;
import com.muyu.marketing.domain.resp.TeamInfoListResp;
import com.muyu.marketing.team.service.ActivityTeamInfoService;
import com.muyu.marketing.team.service.ActivityTeamProductSkuInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 营销团购活动控制层
 *
 * @author DongZeLiang
 * @date 2024-11-20 14:25
 */
@RestController
@RequestMapping("/team")
public class ActivityTeamController {

    @Autowired
    private ActivityTeamInfoService activityTeamInfoService;
    @Autowired
    private ActivityTeamProductSkuInfoService activityTeamProductSkuInfoService;

    /**
     * 查询营销团购活动列表
     * @param teamInfoListReq 活动查询入参
     * @return 活动响应结果
     */
    @PostMapping("/list")
    public Result<TableDataInfo<TeamInfoListResp>> list(@RequestBody TeamInfoListReq teamInfoListReq) {
        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = activityTeamInfoService.query(teamInfoListReq.buildQueryModel());
        List<TeamInfoListResp> respList = tableDataInfo.getRows().stream().map(TeamInfoListResp::listModelBuild).toList();
        return Result.success(
                new TableDataInfo<>(){{
                    setRows(respList);
                    setTotal(tableDataInfo.getTotal());
                }}
        );
    }
//  "msg": "\r\n### Error querying database.  Cause: java.sql.SQLSyntaxErrorException: Unknown column 'remain_stock' in 'field list'" +
//          "\r\n### The error may exist in com/muyu/marketing/team/mapper/ActivityTeamProductSkuInfoMapper.java (best guess)" +
//          "\r\n### The error may involve defaultParameterMap" +
//          "\r\n### The error occurred while setting parameters" +
//          "\r\n### SQL: SELECT id,team_id,product_id,product_sku,team_stock,remain_stock,team_price,create_by,create_time,update_by,update_time,remark FROM activity_team_product_sku_info WHERE id=?" +
//          "\r\n### Cause: java.sql.SQLSyntaxErrorException: Unknown column 'remain_stock' in 'field list'" +
//          "\n; bad SQL grammar []; nested exception is java.sql.SQLSyntaxErrorException: Unknown column 'remain_stock' in 'field list'",


    /**
     * 添加团购活动
     * @param activityTeamInfoSaveReq 添加请求对象
     * @return 结果集
     */
    @PostMapping("/add")
    public Result<String> save(@RequestBody ActivityTeamInfoSaveReq activityTeamInfoSaveReq) {
        activityTeamInfoService.save(ActivityTeamInfoAddModel.addReqBuild(activityTeamInfoSaveReq));
        return Result.success();
    }
    /**
     * 回显团购活动
     */
    @PostMapping("/detail")
    public Result<ActivityTeamDetailResp> findListByTeamId(@RequestParam Long teamId) {
        ActivityTeamDetailResp activityTeamDetailResp = activityTeamInfoService.findListByTeamId(teamId);
        return Result.success(activityTeamDetailResp);
    }
}
